"""
balloon flying 0.0.1 / balloon.py
(C) Paul Giron / Fab Lab BCN 2013

# Includes code from:
# Game basics: copyright by Pete Shinners
#    http://www.pygame.org/docs/tut/intro/intro.html
# Temperature sensor: copyright by (c) Massachusetts Institute of Technology 2009
#    http://academy.cba.mit.edu/classes/input_devices/temp/hello.temp.45.py

"""
#Imports
import sys, os, pygame, pickle,shelve
import serial

from numpy import log

#Key constants
from pygame.locals import *

#Game Constants
PGNAME = "balloon"          #Title for window
BGCOLOR = (192,192,192)  #Default screen BG color
FPS_MAX = 60 


#function to interact with the sensor (Neil G./MIT code)
#redefined to return the temperature
def serialito(parent):
   global filter, eps
   #
   # idle routine
   #
   byte2 = 0
   byte3 = 0
   byte4 = 0
   ser.flush()
   while 1:
      #
      # find framing 
      #
      byte1 = byte2
      byte2 = byte3
      byte3 = byte4
      byte4 = ord(ser.read())
      if ((byte1 == 1) & (byte2 == 2) & (byte3 == 3) & (byte4 == 4)):
         break
   low = ord(ser.read())
   high = ord(ser.read())
   value = 256*high + low
   if (value > 511):
      value -= 1024
   V = 2.5 - value*5.0/(20.0*512.0)
   R = 10000.0/(5.0/V-1.0)
   # NHQ103B375R5
   # R25 10000 (O)
   # B (25/85) 3750 (K)
   # R(T(C)) = R(25)*exp(B*(1/(T(C)+273.15)-(1/(25+273.15))))
   B = 3750.0
   R25 =  10000.0
   T = 1.0/(log(R/R25)/B+(1/(25.0+273.15))) - 273.15
   return T

#Main loop

#
#  check command line arguments
#
if (len(sys.argv) != 2):
   print "command line: baloon serial_port"
   sys.exit()
port = sys.argv[1]
#
# open serial port
# establish connection to 9600 bps
# set the DTR (Data Terminal Ready) in the UART
#
ser = serial.Serial(port,9600)
ser.setDTR()
#




#Init pygame
pygame.init()
clock = pygame.time.Clock()

#set variables
size = width, height = 640, 680
speed = [0, -1]
black = 0, 0, 0

screen = pygame.display.set_mode(size)

#load the image
ball = pygame.image.load("balloon.png")
ballrect = ball.get_rect()
#set on place
ballrect.move_ip(320, 0)


while 1:
    for event in pygame.event.get():
        if event.type == pygame.QUIT: sys.exit()
    
    #capture temp from serialito function
    #equis = serialito("/dev/ttyUSB0")
    equis = serialito(port)
    
    if equis >= 29.500 :
        speed = [0, -1]
    else:
        speed = [0, 1]
    ballrect = ballrect.move(speed)


    print equis
    
    if ballrect.left < 0 or ballrect.right > width:
        speed[0] = -speed[0]
    if ballrect.top < 0 or ballrect.bottom > height:
        speed[1] = -speed[1]

    screen.fill(black)
    screen.blit(ball, ballrect)
    clock.tick(FPS_MAX)
    
    #Update screen and tick fps
    pygame.display.update()
    clock.tick(FPS_MAX)

    #Set the caption
    pygame.display.set_caption(PGNAME)
    pygame.display.flip()